==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/sms/translations/sms_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>SMS-Nick-Name</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Benutze eungebautes Programm</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Eigenes SMS-Programm</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Benutze eigene SMS-Zeichenkette</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Eigene SMS-Zeichenkette</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>SMS-Server</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl Era</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Gesponsort</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Benutzer-Id (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Sende SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Automatisch auswählen</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Provider GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signatur</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>SMS im Verlauf Speichern</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Programm zum Senden von SMS wurde nicht angegeben. Konsultieren Sie bitte die Konfiguration</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Konnte das Kind-Prozess nicht erreichen. Überprüfen Sie, ob das Programm funktioniert</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Der Prozess wurde ungewöhnlich beendet. SMS wurde nicht weschickt</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatische Providerauswahl ist nicht verfügbar. Wählen Sie einen aus.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/sms/translations/sms_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Benutze eungebautes Programm</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Eigenes SMS-Programm</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>SMS-Server</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation>Server T-Mobile.pl Era</translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation>Gesponsort</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>Benutzer-Id (48xxxxxxxxx)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extras</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your nick for SMS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use application custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS custom arguments</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation>Sende SMS...</translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation>Automatisch auswählen</translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation>Provider GSM</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signatur</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>SMS im Verlauf Speichern</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation>Programm zum Senden von SMS wurde nicht angegeben. Konsultieren Sie bitte die Konfiguration</translation>
    </message>
    <message>
        <source> - Select recipient - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Konnte das Kind-Prozess nicht erreichen. Überprüfen Sie, ob das Programm funktioniert</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Der Prozess wurde ungewöhnlich beendet. SMS wurde nicht weschickt</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation>Automatische Providerauswahl ist nicht verfügbar. Wählen Sie einen aus.</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detecting gateway...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Detected gateway: %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sending SMS...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SMS sent</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SmsTokenReadJob</name>
    <message>
        <source>Invalid paremeters for token read job.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading token image...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to fetch token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to read token image.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Waiting for entry of token value...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No token value provided.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Received token value.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
